@@ -22,8 +22,9 @@ from sktime.datatypes._registry import (
     SCITYPE_LIST,
     SCITYPE_REGISTER,
     mtype_to_scitype,
+    scitype_to_mtype,
 )
-from sktime.datatypes._utilities import get_cutoff
+from sktime.datatypes._utilities import get_cutoff, update_data
 from sktime.datatypes._vectorize import VectorizedDF
 
 __all__ = [
@@ -43,7 +44,9 @@ __all__ = [
     "MTYPE_LIST_SERIES",
     "MTYPE_LIST_TABLE",
     "scitype",
+    "scitype_to_mtype",
     "SCITYPE_LIST",
     "SCITYPE_REGISTER",
+    "update_data",
     "VectorizedDF",
 ]
