@@ -263,13 +263,23 @@ def get_window(obj, window_length=None, lag=0):
 
     # numpy3D (Panel) or np.npdarray (Series)
     if isinstance(obj, np.ndarray):
+        # if 2D or 3D, we need to subset by last, not first dimension
+        # if 1D, we need to subset by first dimension
+        # to achieve that effect, we swap first and last in case of 2D, 3D
+        # and always subset on first dimension
+        if obj.ndim > 1:
+            obj = obj.swapaxes(1, -1)
         obj_len = len(obj)
         window_start = max(-window_length - lag, -obj_len)
         window_end = max(-lag, -obj_len)
+        # we need to swap first and last dimension back before returning, if done above
         if window_end == 0:
-            return obj[window_start:]
+            obj_subset = obj[window_start:]
         else:
-            return obj[window_start:window_end]
+            obj_subset = obj[window_start:window_end]
+        if obj.ndim > 1:
+            obj_subset = obj_subset.swapaxes(1, -1)
+        return obj_subset
 
     # pd.DataFrame(Series), pd-multiindex (Panel) and pd_multiindex_hier (Hierarchical)
     if isinstance(obj, pd.DataFrame):
@@ -290,3 +300,89 @@ def get_window(obj, window_length=None, lag=0):
     raise ValueError(
         "bug in get_latest_window, unreachable condition, ifs should be exhaustive"
     )
+
+
+def get_slice(obj, start=None, end=None):
+    """Slice obj with start (inclusive) and end (exclusive) indices.
+
+    Returns time series or time series panel with time indices
+        strictly greater and equal to start index and less than
+        end index.
+
+    Parameters
+    ----------
+    obj : sktime compatible time series Series type or None
+        if not None, must be of one of the following mtypes:
+            pd.Series, pd.DataFrame, np.ndarray, of Series scitype
+            pd.multiindex, numpy3D, nested_univ, df-list, of Panel scitype
+            pd_multiindex_hier, of Hierarchical scitype
+    start : int or timestamp, optional, default = None
+        must be int if obj is int indexed, timestamp if datetime indexed
+        Inclusive start of slice. Default = None.
+        If None, then no slice at the start
+    end : int or timestamp, optional, default = None
+        must be int if obj is int indexed, timestamp if datetime indexed
+        Exclusive end of slice. Default = None
+        If None, then no slice at the end
+    Returns
+    -------
+    obj sub-set sliced for `start` (inclusive) and `end` (exclusive) indices
+        None if obj was None
+    """
+    from sktime.datatypes import check_is_scitype, convert_to
+
+    if (start is None and end is None) or obj is None:
+        return obj
+
+    valid, _, metadata = check_is_scitype(
+        obj, scitype=["Series", "Panel", "Hierarchical"], return_metadata=True
+    )
+    if not valid:
+        raise ValueError("obj must be of Series, Panel, or Hierarchical scitype")
+    obj_in_mtype = metadata["mtype"]
+
+    obj = convert_to(obj, GET_LATEST_WINDOW_SUPPORTED_MTYPES)
+
+    # numpy3D (Panel) or np.npdarray (Series)
+    # Assumes the index is integer so will be exclusive by default
+    if isinstance(obj, np.ndarray):
+        # if 2D or 3D, we need to subset by last, not first dimension
+        # if 1D, we need to subset by first dimension
+        # to achieve that effect, we swap first and last in case of 2D, 3D
+        # and always subset on first dimension
+        if obj.ndim > 1:
+            obj = obj.swapaxes(1, -1)
+        # subsetting
+        if start and end:
+            obj_subset = obj[start:end]
+        elif end:
+            obj_subset = obj[:end]
+        else:
+            obj_subset = obj[start:]
+        # we need to swap first and last dimension back before returning, if done above
+        if obj.ndim > 1:
+            obj_subset = obj_subset.swapaxes(1, -1)
+        return obj_subset
+
+    # pd.DataFrame(Series), pd-multiindex (Panel) and pd_multiindex_hier (Hierarchical)
+    # Assumes the index is pd.Timestamp or pd.Period and ensures the end is
+    # exclusive with slice_select
+    if isinstance(obj, pd.DataFrame):
+        if not isinstance(obj.index, pd.MultiIndex):
+            time_indices = obj.index
+        else:
+            time_indices = obj.index.get_level_values(-1)
+
+        if start and end:
+            slice_select = (time_indices >= start) & (time_indices < end)
+        elif end:
+            slice_select = time_indices < end
+        elif start:
+            slice_select = time_indices >= start
+
+        obj_subset = obj.iloc[slice_select]
+        return convert_to(obj_subset, obj_in_mtype)
+
+    raise ValueError(
+        "bug in get_slice, unreachable condition, ifs should be exhaustive"
+    )
