@@ -1,10 +1,8 @@
-#!/usr/bin/env python3 -u
 # -*- coding: utf-8 -*-
 # copyright: sktime developers, BSD-3-Clause License (see LICENSE file)
+"""Tests for splitters."""
 
-"""Test splitters."""
-
-__author__ = ["Markus Löning", "Kutay Koralturk", "khrapovs"]
+__author__ = ["mloning", "kkoralturk", "khrapovs", "fkiraly"]
 
 import numpy as np
 import pandas as pd
@@ -31,6 +29,7 @@ from sktime.forecasting.tests._config import (
     VALID_INDEX_FH_COMBINATIONS,
 )
 from sktime.utils._testing.forecasting import _make_fh
+from sktime.utils._testing.hierarchical import _make_hierarchical
 from sktime.utils._testing.series import _make_series
 from sktime.utils.datetime import _coerce_duration_to_int
 from sktime.utils.validation import (
@@ -87,9 +86,11 @@ def _check_cutoffs_against_test_windows(cutoffs, windows, fh, y):
     if is_int(fh[-1]):
         expected = np.array([window[-1] - fh[-1] for window in windows])
     elif array_is_timedelta_or_date_offset(fh):
-        expected = np.array(
-            [(y.index[window[-1]] - fh[-1]).to_datetime64() for window in windows]
-        )
+        expected = np.array([])
+        for window in windows:
+            arg = y.index[window[-1]] - fh[-1]
+            val = y.index.get_loc(arg) if arg >= y.index[0] else -1
+            expected = np.append(expected, val)
     else:
         raise ValueError(f"Provided `fh` type is not supported: {type(fh[-1])}")
     np.testing.assert_array_equal(cutoffs, expected)
@@ -97,32 +98,14 @@ def _check_cutoffs_against_test_windows(cutoffs, windows, fh, y):
 
 def _check_cutoffs_against_train_windows(cutoffs, windows, y):
     # Cutoffs should always be the last values of the train windows.
-    if array_is_int(cutoffs):
-        actual = np.array([window[-1] for window in windows[1:]])
-    elif array_is_datetime64(cutoffs):
-        actual = np.array(
-            [y.index[window[-1]].to_datetime64() for window in windows[1:]],
-            dtype="datetime64",
-        )
-    else:
-        raise ValueError(
-            f"Provided `cutoffs` type is not supported: {type(cutoffs[0])}"
-        )
+    assert array_is_int(cutoffs)
+    actual = np.array([window[-1] for window in windows[1:]])
     np.testing.assert_array_equal(actual, cutoffs[1:])
 
     # We treat the first window separately, since it may be empty when setting
     # `start_with_window=False`.
     if len(windows[0]) > 0:
-        if array_is_int(cutoffs):
-            np.testing.assert_array_equal(windows[0][-1], cutoffs[0])
-        elif array_is_datetime64(cutoffs):
-            np.testing.assert_array_equal(
-                y.index[windows[0][-1]].to_datetime64(), cutoffs[0]
-            )
-        else:
-            raise ValueError(
-                f"Provided `cutoffs` type is not supported: {type(cutoffs[0])}"
-            )
+        np.testing.assert_array_equal(windows[0][-1], cutoffs[0])
 
 
 def _check_cv(cv, y, allow_empty_window=False):
@@ -223,7 +206,7 @@ def test_cutoff_window_splitter(y, cutoffs, fh, window_length):
 
 
 @pytest.mark.parametrize("y", TEST_YS)
-@pytest.mark.parametrize("fh", TEST_FHS)
+@pytest.mark.parametrize("fh", [*TEST_FHS, *TEST_FHS_TIMEDELTA])
 @pytest.mark.parametrize("window_length", TEST_WINDOW_LENGTHS)
 @pytest.mark.parametrize("step_length", TEST_STEP_LENGTHS)
 def test_sliding_window_splitter(y, fh, window_length, step_length):
@@ -254,7 +237,7 @@ def test_sliding_window_splitter(y, fh, window_length, step_length):
 
 
 @pytest.mark.parametrize("y", TEST_YS)
-@pytest.mark.parametrize("fh", TEST_FHS)
+@pytest.mark.parametrize("fh", [*TEST_FHS, *TEST_FHS_TIMEDELTA])
 @pytest.mark.parametrize("window_length", TEST_WINDOW_LENGTHS)
 @pytest.mark.parametrize("step_length", TEST_STEP_LENGTHS)
 @pytest.mark.parametrize("initial_window", TEST_INITIAL_WINDOW)
@@ -302,7 +285,7 @@ def _get_n_incomplete_windows(window_length, step_length) -> int:
 
 
 @pytest.mark.parametrize("y", TEST_YS)
-@pytest.mark.parametrize("fh", TEST_FHS)
+@pytest.mark.parametrize("fh", [*TEST_FHS, *TEST_FHS_TIMEDELTA])
 @pytest.mark.parametrize("window_length", TEST_WINDOW_LENGTHS)
 @pytest.mark.parametrize("step_length", TEST_STEP_LENGTHS)
 def test_sliding_window_splitter_start_with_empty_window(
@@ -379,7 +362,7 @@ def _check_expanding_windows(windows):
 
 
 @pytest.mark.parametrize("y", TEST_YS)
-@pytest.mark.parametrize("fh", TEST_FHS)
+@pytest.mark.parametrize("fh", [*TEST_FHS, *TEST_FHS_TIMEDELTA])
 @pytest.mark.parametrize("initial_window", TEST_WINDOW_LENGTHS)
 @pytest.mark.parametrize("step_length", TEST_STEP_LENGTHS)
 def test_expanding_window_splitter_start_with_empty_window(
@@ -411,7 +394,7 @@ def test_expanding_window_splitter_start_with_empty_window(
 
 
 @pytest.mark.parametrize("y", TEST_YS)
-@pytest.mark.parametrize("fh", TEST_FHS)
+@pytest.mark.parametrize("fh", [*TEST_FHS, *TEST_FHS_TIMEDELTA])
 @pytest.mark.parametrize("initial_window", TEST_WINDOW_LENGTHS)
 @pytest.mark.parametrize("step_length", TEST_STEP_LENGTHS)
 def test_expanding_window_splitter(y, fh, initial_window, step_length):
@@ -498,3 +481,69 @@ def _check_train_test_split_y(fh, split):
 
     cutoff = train.index[-1]
     np.testing.assert_array_equal(test.index, fh.to_absolute(cutoff).to_numpy())
+
+
+def test_split_series():
+    """Tests that split_series produces series in the split."""
+    y = _make_series()
+    cv = SlidingWindowSplitter()
+
+    for train, test in cv.split_series(y):
+        assert isinstance(train, pd.Series)
+        assert len(train) == 10
+        assert isinstance(test, pd.Series)
+        assert len(test) == 1
+
+
+def test_split_loc():
+    """Tests that split_loc produces loc indices for train and test."""
+    y = _make_series()
+    cv = SlidingWindowSplitter()
+
+    for train, test in cv.split_loc(y):
+        assert isinstance(train, pd.DatetimeIndex)
+        assert len(train) == 10
+        y.loc[train]
+        assert isinstance(test, pd.DatetimeIndex)
+        assert len(test) == 1
+        y.loc[test]
+
+
+def test_split_series_hier():
+    """Tests that split works with hierarchical data."""
+    hierarchy_levels = (2, 4)
+    n_instances = np.prod(hierarchy_levels)
+    n = 12
+    y = _make_hierarchical(
+        hierarchy_levels=hierarchy_levels, max_timepoints=n, min_timepoints=n
+    )
+    cv = SlidingWindowSplitter()
+
+    for train, test in cv.split(y):
+        assert isinstance(train, np.ndarray)
+        assert train.ndim == 1
+        assert train.dtype == np.int64
+        assert len(train) == 10 * n_instances
+        assert isinstance(test, np.ndarray)
+        assert test.ndim == 1
+        assert test.dtype == np.int64
+        assert len(test) == 1 * n_instances
+
+    for train, test in cv.split_loc(y):
+        assert isinstance(train, pd.MultiIndex)
+        assert len(train) == 10 * n_instances
+        assert train.isin(y.index).all()
+        assert isinstance(test, pd.MultiIndex)
+        assert len(test) == 1 * n_instances
+        assert test.isin(y.index).all()
+
+    def inst_index(y):
+        return set(y.index.droplevel(-1).unique())
+
+    for train, test in cv.split_series(y):
+        assert isinstance(train, pd.DataFrame)
+        assert len(train) == 10 * n_instances
+        assert isinstance(test, pd.DataFrame)
+        assert len(test) == 1 * n_instances
+        assert inst_index(train) == inst_index(y)
+        assert inst_index(test) == inst_index(y)
