@@ -1,6 +1,7 @@
 #!/usr/bin/env python3 -u
 # -*- coding: utf-8 -*-
 # copyright: sktime developers, BSD-3-Clause License (see LICENSE file)
+from logging import warning
 
 import numpy as np
 import pandas as pd
@@ -9,9 +10,7 @@ from sklearn.utils import check_array, check_consistent_length
 from sktime.datatypes import check_is_scitype, convert
 from sktime.performance_metrics.forecasting._classes import _BaseForecastingErrorMetric
 
-# TODO: add formal tests
-# TODO: Adapt score_average to ensure doesn't interfere with multioutput
-#        treatment (both average across columns)
+# TODO: Rework tests now
 
 
 class _BaseProbaForecastingErrorMetric(_BaseForecastingErrorMetric):
@@ -49,7 +48,7 @@ class _BaseProbaForecastingErrorMetric(_BaseForecastingErrorMetric):
     ):
         self.multioutput = multioutput
         self.score_average = score_average
-        super().__init__(func, name=name)
+        super().__init__(func, name=name, multioutput=multioutput)
 
     def __call__(self, y_true, y_pred, **kwargs):
         """Calculate metric value using underlying metric function.
@@ -61,13 +60,12 @@ class _BaseProbaForecastingErrorMetric(_BaseForecastingErrorMetric):
             Ground truth (correct) target values.
 
         y_pred : return object of probabilistic predictition method scitype:y_pred
-            must be at fh and for variables equal to those in y_true
+            must be at fh and for variables equal to those in y_true.
 
         Returns
         -------
         loss : float or 1-column pd.DataFrame with calculated metric value(s)
             metric is always averaged (arithmetic) over fh values
-            if multioutput = "raw_values",
             if multioutput = "raw_values",
                 will have a column level corresponding to variables in y_true
             if multioutput = multioutput = "uniform_average" or or array-like
@@ -91,6 +89,9 @@ class _BaseProbaForecastingErrorMetric(_BaseForecastingErrorMetric):
         y_pred : return object of probabilistic predictition method scitype:y_pred
             must be at fh and for variables equal to those in y_true
 
+        multioutput : string "uniform_average" or "raw_values" determines how\
+            multioutput results will be treated.
+
         Returns
         -------
         loss : float or 1-column pd.DataFrame with calculated metric value(s)
@@ -108,21 +109,58 @@ class _BaseProbaForecastingErrorMetric(_BaseForecastingErrorMetric):
         y_true_inner, y_pred_inner, multioutput = self._check_ys(
             y_true, y_pred, multioutput
         )
-        # pass to inner function
-        out_df = self._evaluate(y_true_inner, y_pred_inner, multioutput, **kwargs)
-        if self.score_average:
-            out_df = out_df.mean(axis=1)
 
-        # unwrap the case where resulting data frame has one entry
-        if self.score_average and multioutput in "uniform_average":
-            out_df = out_df.iloc[0]
-        return out_df
+        # Don't want to include scores for 0 width intervals, makes no sense
+        if 0 in y_pred_inner.columns.get_level_values(1):
+            y_pred_inner = y_pred_inner.drop(0, axis=1, level=1)
+            warning(
+                "Dropping 0 width interval, don't include 0.5 quantile\
+            for interval metrics."
+            )
+
+        # pass to inner function
+        out = self._evaluate(y_true_inner, y_pred_inner, multioutput, **kwargs)
+
+        if self.score_average and multioutput == "uniform_average":
+            out = float(out.mean(axis=1))  # average over all
+        if self.score_average and multioutput == "raw_values":
+            out = out.groupby(axis=1, level=0).mean()  # average over scores
+        if not self.score_average and multioutput == "uniform_average":
+            out = out.groupby(axis=1, level=1).mean()  # average over variables
+        if not self.score_average and multioutput == "raw_values":
+            out = out  # don't average
+
+        if isinstance(out, pd.DataFrame):
+            out = out.squeeze(axis=0)
+
+        return out
 
     def _evaluate(self, y_true, y_pred, multioutput, **kwargs):
+        """Evaluate the desired metric on given inputs.
+
+        Parameters
+        ----------
+        y_true : pd.DataFrame or of shape (fh,) or \
+                (fh, n_outputs) where fh is the forecasting horizon
+            Ground truth (correct) target values.
+
+        y_pred : pd.DataFrame of shape (fh,) or  \
+                (fh, n_outputs)  where fh is the forecasting horizon
+            Forecasted values.
+
+        multioutput : string "uniform_average" or "raw_values" determines how\
+            multioutput results will be treated.
+
+        Returns
+        -------
+        loss : pd.DataFrame of shape (, n_outputs), calculated loss metric.
+        """
         # Default implementation relies on implementation of evaluate_by_index
         try:
             index_df = self._evaluate_by_index(y_true, y_pred, multioutput)
-            return index_df.mean(axis=0)
+            out_df = pd.DataFrame(index_df.mean(axis=0)).T
+            out_df.columns = index_df.columns
+            return out_df
         except RecursionError:
             RecursionError("Must implement one of _evaluate or _evaluate_by_index")
 
@@ -138,6 +176,9 @@ class _BaseProbaForecastingErrorMetric(_BaseForecastingErrorMetric):
         y_pred : return object of probabilistic predictition method scitype:y_pred
             must be at fh and for variables equal to those in y_true
 
+        multioutput : string "uniform_average" or "raw_values" determines how\
+            multioutput results will be treated.
+
         Returns
         -------
         loss : pd.DataFrame of length len(fh), with calculated metric value(s)
@@ -155,20 +196,47 @@ class _BaseProbaForecastingErrorMetric(_BaseForecastingErrorMetric):
         y_true_inner, y_pred_inner, multioutput = self._check_ys(
             y_true, y_pred, multioutput
         )
-        # pass to inner function
-        out_df = self._evaluate_by_index(
-            y_true_inner, y_pred_inner, multioutput, **kwargs
-        )
 
-        if self.score_average:
-            out_df = out_df.mean(axis=1)
-        return out_df
+        # Don't want to include scores for 0 width intervals, makes no sense
+        if 0 in y_pred_inner.columns.get_level_values(1):
+            y_pred_inner = y_pred_inner.drop(0, axis=1, level=1)
+            warning(
+                "Dropping 0 width interval, don't include 0.5 quantile\
+            for interval metrics."
+            )
+
+        # pass to inner function
+        out = self._evaluate_by_index(y_true_inner, y_pred_inner, multioutput, **kwargs)
+
+        if self.score_average and multioutput == "uniform_average":
+            out = out.mean(axis=1)  # average over all
+        if self.score_average and multioutput == "raw_values":
+            out = out.groupby(axis=1, level=0).mean()  # average over scores
+        if not self.score_average and multioutput == "uniform_average":
+            out = out.groupby(axis=1, level=1).mean()  # average over variables
+        if not self.score_average and multioutput == "raw_values":
+            out = out  # don't average
+
+        return out
 
     def _evaluate_by_index(self, y_true, y_pred, multioutput, **kwargs):
         """Logic for finding the metric evaluated at each index.
 
         By default this uses _evaluate to find jackknifed pseudosamples. This
         estimates the error at each of the time points.
+
+        Parameters
+        ----------
+        y_true : pd.Series, pd.DataFrame or np.array of shape (fh,) or \
+            (fh, n_outputs) where fh is the forecasting horizon
+        Ground truth (correct) target values.
+
+        y_pred : pd.Series, pd.DataFrame or np.array of shape (fh,) or  \
+            (fh, n_outputs)  where fh is the forecasting horizon
+            Forecasted values.
+
+        multioutput : string "uniform_average" or "raw_values" determines how \
+            multioutput results will be treated.
         """
         n = y_true.shape[0]
         out_series = pd.Series(index=y_pred.index)
@@ -177,12 +245,14 @@ class _BaseProbaForecastingErrorMetric(_BaseForecastingErrorMetric):
             for i in range(n):
                 out_series[i] = n * x_bar - (n - 1) * self.evaluate(
                     np.vstack((y_true[:i, :], y_true[i + 1 :, :])),  # noqa
-                    np.vstack((y_pred[:i, :], y_pred[i + 1 :, :])),
+                    np.vstack((y_pred[:i, :], y_pred[i + 1 :, :])),  # noqa
                     multioutput,
                 )
             return out_series
         except RecursionError:
-            RecursionError("Must implement one of _evaluate or _evaluate_by_index")
+            raise RecursionError(
+                "Must implement one of _evaluate or _evaluate_by_index"
+            )
 
     def _check_consistent_input(self, y_true, y_pred, multioutput):
         check_consistent_length(y_true, y_pred)
@@ -190,10 +260,10 @@ class _BaseProbaForecastingErrorMetric(_BaseForecastingErrorMetric):
         y_true = check_array(y_true, ensure_2d=False)
 
         if not isinstance(y_pred, pd.DataFrame):
-            ValueError("y_pred should be a dataframe.")
+            raise ValueError("y_pred should be a dataframe.")
 
         if not all(y_pred.dtypes == float):
-            ValueError("Data should be numeric.")
+            raise ValueError("Data should be numeric.")
 
         if y_true.ndim == 1:
             y_true = y_true.reshape((-1, 1))
@@ -233,6 +303,7 @@ class _BaseProbaForecastingErrorMetric(_BaseForecastingErrorMetric):
 
         y_pred_mtype = metadata["mtype"]
         inner_y_pred_mtype = self.get_tag("scitype:y_pred")
+
         y_pred_inner = convert(
             y_pred,
             from_type=y_pred_mtype,
@@ -240,6 +311,13 @@ class _BaseProbaForecastingErrorMetric(_BaseForecastingErrorMetric):
             as_scitype="Proba",
         )
 
+        if inner_y_pred_mtype == "pred_interval":
+            if 0.0 in y_pred_inner.columns.get_level_values(1):
+                for var in y_pred_inner.columns.get_level_values(0):
+                    y_pred_inner[var, 0.0, "upper"] = y_pred_inner[var, 0.0, "lower"]
+
+        y_pred_inner.sort_index(axis=1, level=[0, 1], inplace=True)
+
         y_true, y_pred, multioutput = self._check_consistent_input(
             y_true, y_pred, multioutput
         )
@@ -271,6 +349,15 @@ class _BaseProbaForecastingErrorMetric(_BaseForecastingErrorMetric):
         return alpha
 
     def _handle_multioutput(self, loss, multioutput):
+        """Specificies how multivariate outputs should be handled.
+
+        Parameters
+        ----------
+        loss : float, np.ndarray the evaluated metric value.
+
+        multioutput : string "uniform_average" or "raw_values" determines how \
+            multioutput results will be treated.
+        """
         if isinstance(multioutput, str):
             if multioutput == "raw_values":
                 return loss
@@ -296,8 +383,14 @@ class PinballLoss(_BaseProbaForecastingErrorMetric):
 
     Parameters
     ----------
-    multioutput : string "uniform_average" or "raw_values" determines how multioutput
-    results will be treated
+    multioutput : string "uniform_average" or "raw_values" determines how\
+        multioutput results will be treated.
+
+    score_average : bool, optional, default = True
+        specifies whether scores for each quantile should be averaged.
+
+    alpha (optional) : float, list or np.ndarray, specifies what quantiles to \
+        evaluate metric at.
     """
 
     _tags = {
@@ -319,7 +412,20 @@ class PinballLoss(_BaseProbaForecastingErrorMetric):
             name=name, multioutput=multioutput, score_average=score_average
         )
 
-    def _evaluate(self, y_true, y_pred, multioutput, **kwargs):
+    def _evaluate_by_index(self, y_true, y_pred, multioutput, **kwargs):
+        """Logic for finding the metric evaluated at each index.
+
+        y_true : pd.Series, pd.DataFrame or np.array of shape (fh,) or \
+            (fh, n_outputs) where fh is the forecasting horizon
+            Ground truth (correct) target value`s.
+
+        y_pred : pd.Series, pd.DataFrame or np.array of shape (fh,) or  \
+            (fh, n_outputs)  where fh is the forecasting horizon
+            Forecasted values.
+
+        multioutput : string "uniform_average" or "raw_values"
+            Determines how multioutput results will be treated.
+        """
         alpha = self.alpha
         y_pred_alphas = self._get_alpha_from(y_pred)
         if alpha is None:
@@ -337,38 +443,24 @@ class PinballLoss(_BaseProbaForecastingErrorMetric):
 
         alphas = self._check_alpha(alphas)
 
-        out = [None] * len(alphas)
-        for i, alpha in enumerate(alphas):
-            alpha_preds = y_pred.iloc[
-                :, y_pred.columns.get_level_values(1) == alpha
-            ].to_numpy()
-            diff = y_true - alpha_preds
-            sign = (diff >= 0).astype(diff.dtype)
-            loss = alpha * sign * diff - (1 - alpha) * (1 - sign) * diff
+        alpha_preds = y_pred.iloc[
+            :, [x in alphas for x in y_pred.columns.get_level_values(1)]
+        ]
 
-            loss = np.average(loss, axis=0)
+        alpha_preds_np = alpha_preds.to_numpy()
+        alpha_mat = np.repeat(
+            (alpha_preds.columns.get_level_values(1).to_numpy().reshape(1, -1)),
+            repeats=y_true.shape[0],
+            axis=0,
+        )
 
-            out[i] = self._handle_multioutput(loss, multioutput)
+        y_true_np = np.repeat(y_true, axis=1, repeats=len(alphas))
+        diff = y_true_np - alpha_preds_np
+        sign = (diff >= 0).astype(diff.dtype)
+        loss = alpha_mat * sign * diff - (1 - alpha_mat) * (1 - sign) * diff
 
-        out_df = pd.DataFrame([out], columns=alphas)
-        return out_df
+        out_df = pd.DataFrame(loss, columns=alpha_preds.columns)
 
-    def _evaluate_by_index(self, y_true, y_pred, multioutput, **kwargs):
-        alphas = self._get_alpha_from(y_pred)
-
-        n = len(y_true)
-        out = np.full([n, len(alphas)], None)
-        for i, alpha in enumerate(alphas):
-            alpha_preds = y_pred.iloc[
-                :, y_pred.columns.get_level_values(1) == alpha
-            ].to_numpy()
-            diff = y_true - alpha_preds
-            sign = (diff >= 0).astype(diff.dtype)
-            loss = alpha * sign * diff - (1 - alpha) * (1 - sign) * diff
-
-            out[:, i] = self._handle_multioutput(loss, multioutput)
-
-        out_df = pd.DataFrame(out, index=y_pred.index, columns=alphas)
         return out_df
 
     @classmethod
@@ -377,3 +469,146 @@ class PinballLoss(_BaseProbaForecastingErrorMetric):
         params1 = {}
         params2 = {"alpha": [0.1, 0.5, 0.9]}
         return [params1, params2]
+
+
+class EmpiricalCoverage(_BaseProbaForecastingErrorMetric):
+    """Evaluate the pinball loss at all quantiles given in data.
+
+    Parameters
+    ----------
+    multioutput : string "uniform_average" or "raw_values" determines how\
+        multioutput results will be treated.
+
+    score_average : bool, optional, default = True
+        specifies whether scores for each quantile should be averaged.
+    """
+
+    _tags = {
+        "scitype:y_pred": "pred_interval",
+        "lower_is_better": False,
+    }
+
+    def __init__(self, multioutput="uniform_average", score_average=True):
+        name = "EmpiricalCoverage"
+        self.score_average = score_average
+        self.multioutput = multioutput
+        super().__init__(
+            name=name, score_average=score_average, multioutput=multioutput
+        )
+
+    def _evaluate_by_index(self, y_true, y_pred, multioutput, **kwargs):
+        """Logic for finding the metric evaluated at each index.
+
+        y_true : pd.Series, pd.DataFrame or np.array of shape (fh,) or \
+            (fh, n_outputs) where fh is the forecasting horizon
+            Ground truth (correct) target values.
+
+        y_pred : pd.Series, pd.DataFrame or np.array of shape (fh,) or  \
+            (fh, n_outputs)  where fh is the forecasting horizon
+            Forecasted values.
+
+        multioutput : string "uniform_average" or "raw_values" determines how \
+            multioutput results will be treated.
+        """
+        lower = y_pred.iloc[:, y_pred.columns.get_level_values(2) == "lower"].to_numpy()
+        upper = y_pred.iloc[:, y_pred.columns.get_level_values(2) == "upper"].to_numpy()
+
+        if not isinstance(y_true, np.ndarray):
+            y_true_np = y_true.to_numpy()
+        else:
+            y_true_np = y_true
+        if y_true_np.ndim == 1:
+            y_true_np = y_true.reshape(-1, 1)
+
+        scores = np.unique(np.round(y_pred.columns.get_level_values(1), 7))
+        no_scores = len(scores)
+        vars = np.unique(y_pred.columns.get_level_values(0))
+
+        y_true_np = np.tile(y_true_np, no_scores)
+
+        truth_array = (y_true_np > lower).astype(int) * (y_true_np < upper).astype(int)
+
+        out_df = pd.DataFrame(
+            truth_array, columns=pd.MultiIndex.from_product([vars, scores])
+        )
+
+        return out_df
+
+    @classmethod
+    def get_test_params(self):
+        """Retrieve test parameters."""
+        params1 = {}
+        return [params1]
+
+
+class ConstraintViolation(_BaseProbaForecastingErrorMetric):
+    """Evaluate the pinball loss at all quantiles given in data.
+
+    Parameters
+    ----------
+    multioutput : string "uniform_average" or "raw_values" determines how\
+        multioutput results will be treated.
+
+    score_average : bool, optional, default = True
+        specifies whether scores for each quantile should be averaged.
+    """
+
+    _tags = {
+        "scitype:y_pred": "pred_interval",
+        "lower_is_better": True,
+    }
+
+    def __init__(self, multioutput="uniform_average", score_average=True):
+        name = "ConstraintViolation"
+        self.score_average = score_average
+        self.multioutput = multioutput
+        super().__init__(
+            name=name, score_average=score_average, multioutput=multioutput
+        )
+
+    def _evaluate_by_index(self, y_true, y_pred, multioutput, **kwargs):
+        """Logic for finding the metric evaluated at each index.
+
+        y_true : pd.Series, pd.DataFrame or np.array of shape (fh,) or \
+            (fh, n_outputs) where fh is the forecasting horizon
+            Ground truth (correct) target values.
+
+        y_pred : pd.Series, pd.DataFrame or np.array of shape (fh,) or  \
+            (fh, n_outputs)  where fh is the forecasting horizon
+            Forecasted values.
+
+        multioutput : string "uniform_average" or "raw_values" determines how \
+            multioutput results will be treated.
+        """
+        lower = y_pred.iloc[:, y_pred.columns.get_level_values(2) == "lower"].to_numpy()
+        upper = y_pred.iloc[:, y_pred.columns.get_level_values(2) == "upper"].to_numpy()
+
+        if not isinstance(y_true, np.ndarray):
+            y_true_np = y_true.to_numpy()
+        else:
+            y_true_np = y_true
+
+        if y_true_np.ndim == 1:
+            y_true_np = y_true.reshape(-1, 1)
+
+        scores = np.unique(np.round(y_pred.columns.get_level_values(1), 7))
+        no_scores = len(scores)
+        vars = np.unique(y_pred.columns.get_level_values(0))
+
+        y_true_np = np.tile(y_true_np, no_scores)
+
+        int_distance = ((y_true_np < lower).astype(int) * abs(lower - y_true_np)) + (
+            (y_true_np > upper).astype(int) * abs(y_true_np - upper)
+        )
+
+        out_df = pd.DataFrame(
+            int_distance, columns=pd.MultiIndex.from_product([vars, scores])
+        )
+
+        return out_df
+
+    @classmethod
+    def get_test_params(self):
+        """Retrieve test parameters."""
+        params1 = {}
+        return [params1]
