@@ -16,7 +16,6 @@ from inspect import getfullargspec, isclass, signature
 import joblib
 import numpy as np
 import pytest
-from sklearn import clone
 from sklearn.utils._testing import set_random_state
 from sklearn.utils.estimator_checks import (
     check_get_params_invariance as _check_get_params_invariance,
@@ -52,6 +51,7 @@ from sktime.utils._testing.estimator_checks import (
     _list_required_methods,
 )
 from sktime.utils._testing.scenarios_getter import retrieve_scenarios
+from sktime.utils.validation._dependencies import _check_dl_dependencies
 
 
 class BaseFixtureGenerator:
@@ -86,9 +86,13 @@ class BaseFixtureGenerator:
         ranges over estimator classes not excluded by EXCLUDE_ESTIMATORS, EXCLUDED_TESTS
     estimator_instance: instance of estimator inheriting from BaseObject
         ranges over estimator classes not excluded by EXCLUDE_ESTIMATORS, EXCLUDED_TESTS
-        instances are generated by create_test_instance class method
+        instances are generated by create_test_instance class method of estimator_class
     scenario: instance of TestScenario
         ranges over all scenarios returned by retrieve_scenarios
+        applicable for estimator_class or estimator_instance
+    method_nsc: string, name of estimator method
+        ranges over all "predict"-like, non-state-changing methods
+        of estimator_instance or estimator_class that the class/object implements
     """
 
     # class variables which can be overridden by descendants
@@ -97,7 +101,12 @@ class BaseFixtureGenerator:
     estimator_type_filter = None
 
     # which sequence the conditional fixtures are generated in
-    fixture_sequence = ["estimator_class", "estimator_instance", "scenario"]
+    fixture_sequence = [
+        "estimator_class",
+        "estimator_instance",
+        "scenario",
+        "method_nsc",
+    ]
 
     # which fixtures are indirect, e.g., have an additional pytest.fixture block
     #   to generate an indirect fixture at runtime. Example: estimator_instance
@@ -230,7 +239,7 @@ class BaseFixtureGenerator:
     def estimator_instance(self, request):
         """estimator_instance fixture definition for indirect use."""
         # esetimator_instance is cloned at the start of every test
-        return clone(request.param)
+        return request.param.clone()
 
     def _generate_scenario(self, test_name, **kwargs):
         """Return estimator test scenario.
@@ -283,12 +292,50 @@ class BaseFixtureGenerator:
 
         return False
 
+    def _generate_method_nsc(self, test_name, **kwargs):
+        """Return estimator test scenario.
+
+        Fixtures parametrized
+        ---------------------
+        method_nsc: string, for non-state-changing estimator methods
+            ranges over all "predict"-like, non-state-changing estimator methods
+        """
+        # ensure cls is a class
+        if "estimator_class" in kwargs.keys():
+            obj = kwargs["estimator_class"]
+            cls = obj
+        elif "estimator_instance" in kwargs.keys():
+            obj = kwargs["estimator_instance"]
+            cls = type(obj)
+        else:
+            return []
+
+        # complete list of all non-state-changing methods
+        nsc_list = NON_STATE_CHANGING_METHODS
+
+        # subset to the methods that x has implemented
+        nsc_list = [x for x in nsc_list if _has_capability(obj, x)]
+
+        # remove predict_proba for forecasters, if tensorflow-proba is not installed
+        # this ensures that predict_proba, which requires it, is not called in testing
+        if issubclass(cls, BaseForecaster):
+            if not _check_dl_dependencies(severity="none"):
+                nsc_list = list(set(nsc_list).difference(["predict_proba"]))
+
+        return nsc_list
+
 
 class QuickTester:
     """Mixin class which adds the run_tests method to run tests on one estimator."""
 
     def run_tests(
-        self, estimator, return_exceptions=True, tests_to_run=None, fixtures_to_run=None
+        self,
+        estimator,
+        return_exceptions=True,
+        tests_to_run=None,
+        fixtures_to_run=None,
+        tests_to_exclude=None,
+        fixtures_to_exclude=None,
     ):
         """Run all tests on one single estimator.
 
@@ -316,6 +363,11 @@ class QuickTester:
             If both tests_to_run and fixtures_to_run are provided, runs the *union*,
             i.e., all test-fixture combinations for tests in tests_to_run,
                 plus all test-fixture combinations in fixtures_to_run.
+        tests_to_exclude : str or list of str, names of tests to exclude. default = None
+            removes tests that should not be run, after subsetting via tests_to_run.
+        fixtures_to_exclude : str or list of str, fixtures to exclude. default = None
+            removes test-fixture combinations that should not be run.
+            This is done after subsetting via fixtures_to_run.
 
         Returns
         -------
@@ -349,6 +401,12 @@ class QuickTester:
         fixtures_to_run = self._check_None_str_or_list_of_str(
             fixtures_to_run, var_name="fixtures_to_run"
         )
+        tests_to_exclude = self._check_None_str_or_list_of_str(
+            tests_to_exclude, var_name="tests_to_exclude"
+        )
+        fixtures_to_exclude = self._check_None_str_or_list_of_str(
+            fixtures_to_exclude, var_name="fixtures_to_exclude"
+        )
 
         # retrieve tests from self
         test_names = [attr for attr in dir(self) if attr.startswith("test")]
@@ -367,7 +425,7 @@ class QuickTester:
             return [estimator_class], [estimator_class.__name__]
 
         def _generate_estimator_instance(test_name, **kwargs):
-            return [clone(estimator)], [estimator_class.__name__]
+            return [estimator.clone()], [estimator_class.__name__]
 
         def _generate_estimator_instance_cls(test_name, **kwargs):
             return estimator_class.create_test_instances_and_names()
@@ -393,6 +451,12 @@ class QuickTester:
                 test_names_subset += list(set(test_names).intersection(tests_from_fixt))
             test_names_subset = list(set(test_names_subset))
 
+        # sub-setting by removing all tests from tests_to_exclude
+        if tests_to_exclude is not None:
+            test_names_subset = list(
+                set(test_names_subset).difference(tests_to_exclude)
+            )
+
         # the below loops run all the tests and collect the results here:
         results = dict()
         # loop A: we loop over all the tests
@@ -451,6 +515,8 @@ class QuickTester:
                 #  key is identical to the pytest test-fixture string identifier
                 if fixtures_to_run is not None and key not in fixtures_to_run:
                     continue
+                if fixtures_to_exclude is not None and key in fixtures_to_exclude:
+                    continue
 
                 if return_exceptions:
                     try:
@@ -716,16 +782,19 @@ class TestAllEstimators(BaseFixtureGenerator, QuickTester):
     def test_clone(self, estimator_instance):
         """Check we can call clone from scikit-learn."""
         estimator = estimator_instance
-        clone(estimator)
+        estimator.clone()
 
     def test_repr(self, estimator_instance):
         """Check we can call repr."""
         estimator = estimator_instance
         repr(estimator)
 
-    def check_constructor(self, estimator_class):
-        """Check that the constructor behaves correctly."""
+    def test_constructor(self, estimator_class):
+        """Check that the constructor has correct signature and behaves correctly."""
+        assert getfullargspec(estimator_class.__init__).varkw is None
+
         estimator = estimator_class.create_test_instance()
+        assert isinstance(estimator, estimator_class)
 
         # Ensure that each parameter is set in init
         init_params = _get_args(type(estimator).__init__)
@@ -830,58 +899,58 @@ class TestAllEstimators(BaseFixtureGenerator, QuickTester):
             fit_return is estimator_instance
         ), f"Estimator: {estimator_instance} does not return self when calling fit"
 
-    def test_raises_not_fitted_error(self, estimator_instance, scenario):
+    def test_raises_not_fitted_error(self, estimator_instance, scenario, method_nsc):
         """Check that we raise appropriate error for unfitted estimators."""
+        estimator = estimator_instance
+
         # pairwise transformers are exempted from this test, since they have no fitting
         PWTRAFOS = (BasePairwiseTransformer, BasePairwiseTransformerPanel)
-        excepted = isinstance(estimator_instance, PWTRAFOS)
+        excepted = isinstance(estimator, PWTRAFOS)
         if excepted:
             return None
 
-        # call methods without prior fitting and check that they raise our
-        # NotFittedError
-        for method in NON_STATE_CHANGING_METHODS:
-            if _has_capability(estimator_instance, method):
-                with pytest.raises(NotFittedError, match=r"has not been fitted"):
-                    scenario.run(estimator_instance, method_sequence=[method])
+        # call methods without prior fitting and check that they raise NotFittedError
+        with pytest.raises(NotFittedError, match=r"has not been fitted"):
+            scenario.run(estimator_instance, method_sequence=[method_nsc])
 
-    def test_fit_idempotent(self, estimator_instance, scenario):
+    def test_fit_idempotent(self, estimator_instance, scenario, method_nsc):
         """Check that calling fit twice is equivalent to calling it once."""
         estimator = estimator_instance
 
-        # todo: may have to rework this, due to "if estimator has param"
-        for method in NON_STATE_CHANGING_METHODS:
-            # for now, we have to skip predict_proba, since current output comparison
-            #   does not work for tensorflow Distribution
-            if (
-                isinstance(estimator_instance, BaseForecaster)
-                and method == "predict_proba"
-            ):
-                continue
-            if _has_capability(estimator, method):
-                set_random_state(estimator)
-                results = scenario.run(
-                    estimator,
-                    method_sequence=["fit", method],
-                    return_all=True,
-                    deepcopy_return=True,
-                )
+        # for now, we have to skip predict_proba, since current output comparison
+        #   does not work for tensorflow Distribution
+        if (
+            isinstance(estimator_instance, BaseForecaster)
+            and method_nsc == "predict_proba"
+        ):
+            return None
 
-                estimator = results[0]
-                set_random_state(estimator)
+        # run fit plus method_nsc once, save results
+        set_random_state(estimator)
+        results = scenario.run(
+            estimator,
+            method_sequence=["fit", method_nsc],
+            return_all=True,
+            deepcopy_return=True,
+        )
 
-                results_2nd = scenario.run(
-                    estimator,
-                    method_sequence=["fit", method],
-                    return_all=True,
-                    deepcopy_return=True,
-                )
+        estimator = results[0]
+        set_random_state(estimator)
 
-                _assert_array_almost_equal(
-                    results[1],
-                    results_2nd[1],
-                    # err_msg=f"Idempotency check failed for method {method}",
-                )
+        # run fit plus method_nsc a second time
+        results_2nd = scenario.run(
+            estimator,
+            method_sequence=["fit", method_nsc],
+            return_all=True,
+            deepcopy_return=True,
+        )
+
+        # check results are equal
+        _assert_array_almost_equal(
+            results[1],
+            results_2nd[1],
+            # err_msg=f"Idempotency check failed for method {method}",
+        )
 
     def test_fit_does_not_overwrite_hyper_params(self, estimator_instance, scenario):
         """Check that we do not overwrite hyper-parameters in fit."""
@@ -912,7 +981,9 @@ class TestAllEstimators(BaseFixtureGenerator, QuickTester):
                 % (estimator.__class__.__name__, param_name, original_value, new_value)
             )
 
-    def test_methods_do_not_change_state(self, estimator_instance, scenario):
+    def test_methods_do_not_change_state(
+        self, estimator_instance, scenario, method_nsc
+    ):
         """Check that non-state-changing methods do not change state.
 
         Check that methods that are not supposed to change attributes of the
@@ -922,25 +993,24 @@ class TestAllEstimators(BaseFixtureGenerator, QuickTester):
         estimator = estimator_instance
         set_random_state(estimator)
 
-        for method in NON_STATE_CHANGING_METHODS:
-            if _has_capability(estimator, method):
+        # dict_before = copy of dictionary of estimator before predict, post fit
+        _ = scenario.run(estimator, method_sequence=["fit"])
+        dict_before = estimator.__dict__.copy()
 
-                # dict_before = copy of dictionary of estimator before predict, post fit
-                _ = scenario.run(estimator, method_sequence=["fit"])
-                dict_before = estimator.__dict__.copy()
+        # dict_after = dictionary of estimator after predict and fit
+        _ = scenario.run(estimator, method_sequence=[method_nsc])
+        dict_after = estimator.__dict__
 
-                # dict_after = dictionary of estimator after predict and fit
-                _ = scenario.run(estimator, method_sequence=[method])
-                dict_after = estimator.__dict__
+        is_equal, msg = deep_equals(dict_after, dict_before, return_msg=True)
+        assert is_equal, (
+            f"Estimator: {type(estimator).__name__} changes __dict__ "
+            f"during {method_nsc}, "
+            f"reason/location of discrepancy (x=after, y=before): {msg}"
+        )
 
-                is_equal, msg = deep_equals(dict_after, dict_before, return_msg=True)
-                assert is_equal, (
-                    f"Estimator: {type(estimator).__name__} changes __dict__ "
-                    f"during {method}, "
-                    f"reason/location of discrepancy (x=after, y=before): {msg}"
-                )
-
-    def test_methods_have_no_side_effects(self, estimator_instance, scenario):
+    def test_methods_have_no_side_effects(
+        self, estimator_instance, scenario, method_nsc
+    ):
         """Check that calling methods has no side effects on args."""
         estimator = estimator_instance
 
@@ -957,62 +1027,56 @@ class TestAllEstimators(BaseFixtureGenerator, QuickTester):
             fit_args_before, fit_args_after
         ), f"Estimator: {estimator} has side effects on arguments of fit"
 
-        for method in NON_STATE_CHANGING_METHODS:
-            if _has_capability(estimator, method):
-                # Fit the model, get args before and after
-                _, args_after = scenario.run(
-                    estimator, method_sequence=[method], return_args=True
-                )
-                method_args_after = args_after[0]
-                method_args_before = scenario.get_args(method, estimator)
+        # Fit the model, get args before and after
+        _, args_after = scenario.run(
+            estimator, method_sequence=[method_nsc], return_args=True
+        )
+        method_args_after = args_after[0]
+        method_args_before = scenario.get_args(method_nsc, estimator)
 
-                assert deep_equals(
-                    method_args_after, method_args_before
-                ), f"Estimator: {estimator} has side effects on arguments of {method}"
+        assert deep_equals(
+            method_args_after, method_args_before
+        ), f"Estimator: {estimator} has side effects on arguments of {method_nsc}"
 
-    def test_persistence_via_pickle(self, estimator_instance, scenario):
+    def test_persistence_via_pickle(self, estimator_instance, scenario, method_nsc):
         """Check that we can pickle all estimators."""
+        # escape predict_proba for forecasters, tfp distributions cannot be pickled
+        if (
+            isinstance(estimator_instance, BaseForecaster)
+            and method_nsc == "predict_proba"
+        ):
+            return None
+
         estimator = estimator_instance
         set_random_state(estimator)
         # Fit the model, get args before and after
         scenario.run(estimator, method_sequence=["fit"], return_args=True)
 
         # Generate results before pickling
-        results = {}
-        for method in NON_STATE_CHANGING_METHODS:
-            if _has_capability(estimator, method):
-                results[method] = scenario.run(estimator, method_sequence=[method])
+        vanilla_result = scenario.run(estimator, method_sequence=[method_nsc])
 
         # Pickle and unpickle
         pickled_estimator = pickle.dumps(estimator)
         unpickled_estimator = pickle.loads(pickled_estimator)
 
-        # Compare against results after pickling
-        for method, vanilla_result in results.items():
-            # escape predict_proba for forecasters, tfp distributions cannot be pickled
-            if (
-                isinstance(estimator_instance, BaseForecaster)
-                and method == "predict_proba"
-            ):
-                continue
-            unpickled_result = scenario.run(
-                unpickled_estimator, method_sequence=[method]
-            )
+        unpickled_result = scenario.run(
+            unpickled_estimator, method_sequence=[method_nsc]
+        )
 
-            msg = (
-                f"Results of {method} differ between when pickling and not pickling, "
-                f"estimator {type(estimator_instance).__name__}"
-            )
-            _assert_array_almost_equal(
-                vanilla_result,
-                unpickled_result,
-                decimal=6,
-                err_msg=msg,
-            )
+        msg = (
+            f"Results of {method_nsc} differ between when pickling and not pickling, "
+            f"estimator {type(estimator_instance).__name__}"
+        )
+        _assert_array_almost_equal(
+            vanilla_result,
+            unpickled_result,
+            decimal=6,
+            err_msg=msg,
+        )
 
     # todo: this needs to be diagnosed and fixed - temporary skip
     @pytest.mark.skip(reason="hangs on mac and unix remote tests")
-    def test_multiprocessing_idempotent(self, estimator_instance, scenario):
+    def test_multiprocessing_idempotent(self, estimator_instance, scenario, method_nsc):
         """Test that single and multi-process run results are identical.
 
         Check that running an estimator on a single process is no different to running
@@ -1023,30 +1087,28 @@ class TestAllEstimators(BaseFixtureGenerator, QuickTester):
         params = estimator_instance.get_params()
 
         if "n_jobs" in params:
-            for method in NON_STATE_CHANGING_METHODS:
-                if _has_capability(estimator_instance, method):
-                    # run on a single process
-                    # -----------------------
-                    estimator = deepcopy(estimator_instance)
-                    estimator.set_params(n_jobs=1)
-                    set_random_state(estimator)
-                    result_single_process = scenario.run(
-                        estimator, method_sequence=["fit", method]
-                    )
+            # run on a single process
+            # -----------------------
+            estimator = deepcopy(estimator_instance)
+            estimator.set_params(n_jobs=1)
+            set_random_state(estimator)
+            result_single_process = scenario.run(
+                estimator, method_sequence=["fit", method_nsc]
+            )
 
-                    # run on multiple processes
-                    # -------------------------
-                    estimator = deepcopy(estimator_instance)
-                    estimator.set_params(n_jobs=-1)
-                    set_random_state(estimator)
-                    result_multiple_process = scenario.run(
-                        estimator, method_sequence=["fit", method]
-                    )
-                    _assert_array_equal(
-                        result_single_process,
-                        result_multiple_process,
-                        err_msg="Results are not equal for n_jobs=1 and n_jobs=-1",
-                    )
+            # run on multiple processes
+            # -------------------------
+            estimator = deepcopy(estimator_instance)
+            estimator.set_params(n_jobs=-1)
+            set_random_state(estimator)
+            result_multiple_process = scenario.run(
+                estimator, method_sequence=["fit", method_nsc]
+            )
+            _assert_array_equal(
+                result_single_process,
+                result_multiple_process,
+                err_msg="Results are not equal for n_jobs=1 and n_jobs=-1",
+            )
 
     def test_valid_estimator_class_tags(self, estimator_class):
         """Check that Estimator class tags are in VALID_ESTIMATOR_TAGS."""
