@@ -53,7 +53,6 @@ from typing import Union
 
 import numpy as np
 import pandas as pd
-from sklearn.base import clone
 
 from sktime.base import BaseEstimator
 from sktime.datatypes import (
@@ -64,7 +63,7 @@ from sktime.datatypes import (
     mtype_to_scitype,
 )
 from sktime.datatypes._series_as_panel import convert_to_scitype
-from sktime.utils.sklearn import is_sklearn_transformer
+from sktime.utils.sklearn import is_sklearn_classifier, is_sklearn_transformer
 
 # single/multiple primitives
 Primitive = Union[np.integer, int, float, str]
@@ -161,15 +160,16 @@ class BaseTransformer(BaseEstimator):
             not nested, contains only non-TransformerPipeline `sktime` transformers
         """
         from sktime.transformations.compose import TransformerPipeline
-        from sktime.transformations.series.adapt import TabularToSeriesAdaptor
 
         # we wrap self in a pipeline, and concatenate with the other
         #   the TransformerPipeline does the rest, e.g., case distinctions on other
-        if isinstance(other, BaseTransformer):
+        if (
+            isinstance(other, BaseTransformer)
+            or is_sklearn_classifier(other)
+            or is_sklearn_transformer(other)
+        ):
             self_as_pipeline = TransformerPipeline(steps=[self])
             return self_as_pipeline * other
-        elif is_sklearn_transformer(other):
-            return self * TabularToSeriesAdaptor(other)
         else:
             return NotImplemented
 
@@ -189,15 +189,12 @@ class BaseTransformer(BaseEstimator):
             not nested, contains only non-TransformerPipeline `sktime` transformers
         """
         from sktime.transformations.compose import TransformerPipeline
-        from sktime.transformations.series.adapt import TabularToSeriesAdaptor
 
         # we wrap self in a pipeline, and concatenate with the other
         #   the TransformerPipeline does the rest, e.g., case distinctions on other
-        if isinstance(other, BaseTransformer):
+        if isinstance(other, BaseTransformer) or is_sklearn_transformer(other):
             self_as_pipeline = TransformerPipeline(steps=[self])
             return other * self_as_pipeline
-        elif is_sklearn_transformer(other):
-            return TabularToSeriesAdaptor(other) * self
         else:
             return NotImplemented
 
@@ -277,8 +274,8 @@ class BaseTransformer(BaseEstimator):
         -------
         self : a fitted instance of the estimator
         """
-        # if fit is called, fitted state is re-set
-        self._is_fitted = False
+        # if fit is called, estimator is reset, including fitted state
+        self.reset()
 
         # skip everything if fit_is_empty is True
         if self.get_tag("fit_is_empty"):
@@ -887,7 +884,7 @@ class BaseTransformer(BaseEstimator):
             if methodname == "fit":
                 self.transformers_ = pd.DataFrame(index=idx, columns=["transformers"])
                 for i in range(n):
-                    self.transformers_.iloc[i, 0] = clone(self)
+                    self.transformers_.iloc[i, 0] = self.clone()
 
             # fit/update the i-th transformer with the i-th series/panel
             for i in range(n):
@@ -924,7 +921,7 @@ class BaseTransformer(BaseEstimator):
                 # fit/transform the i-th series/panel with a new clone of self
                 Xts = []
                 for i in range(n):
-                    transformer = clone(self).fit(X=Xs[i], y=ys[i], **kwargs)
+                    transformer = self.clone().fit(X=Xs[i], y=ys[i], **kwargs)
                     method = getattr(transformer, methodname)
                     Xts += [method(X=Xs[i], y=ys[i], **kwargs)]
                 Xt = X.reconstruct(Xts, overwrite_index=False)
