@@ -17,6 +17,7 @@ from sklearn.utils.validation import check_random_state
 from sktime.alignment.base import BaseAligner
 from sktime.annotation.base import BaseSeriesAnnotator
 from sktime.classification.base import BaseClassifier
+from sktime.classification.early_classification import BaseEarlyClassifier
 from sktime.clustering.base import BaseClusterer
 from sktime.datatypes._panel._check import is_nested_dataframe
 from sktime.dists_kernels import BasePairwiseTransformer, BasePairwiseTransformerPanel
@@ -167,7 +168,9 @@ def _make_predict_args(estimator, **kwargs):
     if isinstance(estimator, BaseForecaster):
         fh = 1
         return (fh,)
-    elif isinstance(estimator, (BaseClassifier, BaseRegressor, BaseClusterer)):
+    elif isinstance(
+        estimator, (BaseClassifier, BaseEarlyClassifier, BaseRegressor, BaseClusterer)
+    ):
         X = _make_panel_X(**kwargs)
         return (X,)
     elif isinstance(estimator, BaseSeriesAnnotator):
@@ -355,4 +358,7 @@ def _has_capability(est, method: str) -> bool:
         if method == "predict_proba" and isinstance(est, ALWAYS_HAVE_PREDICT_PROBA):
             return True
         return get_tag(est, "capability:pred_int", False)
+    # skip transform for forecasters that have it - pipelines
+    if method == "transform" and isinstance(est, BaseForecaster):
+        return False
     return True
